import json


class OpenAIProvider:

    def __init__(self, response) -> None:
        self.response = response
        self.request_type = response.object


    def build_object(self, result, prompt, model, tokens):
        return {
            "result": result[:200],
            "provider": "openai",
            "prompt": prompt,
            "model": model,
            "tokens": tokens,
            "response": json.dumps(self.response)
        }


    def process_chat_completions(self, *args, **kwargs):
        result = self.response.choices[0].message.content
        prompt = kwargs.get("messages")[0].get("content")
        return self.build_object(
            result=result,
            prompt=prompt,
            model=kwargs["model"],
            tokens=self.response.usage.total_tokens,
        )

    def process_completion(self, *args, **kwargs):
        result = self.response.choices[0].text
        prompt = kwargs["prompt"]
        return self.build_object(
            result=result,
            prompt=prompt,
            model=kwargs["model"],
            tokens=self.response.usage.total_tokens,
        )


    def process_response(self, *args, **kwargs) -> None:
        if self.request_type == "chat.completion":
            return self.process_chat_completions(*args, **kwargs)
        
        if self.request_type == "completion":
            return self.process_completion(*args, **kwargs)

        return

        


from photon.providers.openai import OpenAIProvider


class PhotonProcessor:

    def __init__(self, provider: str = None, response: dict = None, *args, **kwargs) -> None:
        self.provider = provider
        self.args = args
        self.kwargs = kwargs
        self.response = response
        self.providers = ["openai", "anthropic", "replicate"] # TODO: Add more providers

    def process_provider(self, *args, **kwargs) -> None:
        # Check if provider is valid
        if self.provider not in self.providers:
            raise ValueError(f"Provider must be one of {self.providers}")
        
        if self.provider == "openai":
            provider = OpenAIProvider(self.response)
            return provider.process_response(*args, **kwargs)
            # Do something

        return None


from setuptools import find_packages, setup

VERSION = "0.0.6"
DESCRIPTION = ""
LONG_DESCRIPTION = ""

setup(
    name="photondemo",
    version=VERSION,
    author="Charlie Day",
    url="https://github.com/charliemday/photondemo",
    author_email="",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[
        'requests',
    ],  # add any additional packages that
    # needs to be installed along with your package
    keywords=["python"],
    classifiers=[],
)





import requests


class PhotonLogger:
    def __init__(self, *args, **kwargs) -> None:
        self.photon_url = "https://beacon-demo-production.up.railway.app/api"

    def log_output(self, payload):
        endpoint = "/prompts/log-prompt/"
        url = self.photon_url + endpoint
        response = requests.post(url, json=payload) 
        return response